=== modified file 'Makefile'
--- Makefile	2007-08-07 19:33:11 +0000
+++ Makefile	2007-08-20 04:10:21 +0000
@@ -26,10 +26,9 @@
 	python setup.py build_ext -i
 
 check: docs extensions
-	python -Werror ./bzr selftest -v $(tests)
+	python -Werror -O ./bzr selftest -1v $(tests)
 	@echo "Running all tests with no locale."
-	LC_CTYPE= LANG=C LC_ALL= ./bzr selftest -v $(tests)
-	python -O -Werror ./bzr selftest -v $(tests)
+	LC_CTYPE= LANG=C LC_ALL= ./bzr selftest -1v $(tests)
 
 check-msgeditor:
 	./bzr --no-plugins selftest -v msgeditor

=== modified file 'NEWS'
--- NEWS	2007-08-17 07:15:28 +0000
+++ NEWS	2007-08-20 05:48:40 +0000
@@ -1,5 +1,12 @@
 IN DEVELOPMENT
 
+  CHANGES:
+
+   * The default branch and repository format has changed to 
+     ``dirstate-tags``, so tag commands are active by default.
+     This format is compatible with Bazaar 0.15 and later.
+     (Martin Pool)
+
   FEATURES:
 
     * New option ``--author`` in ``bzr commit`` to specify the author of the
@@ -10,6 +17,11 @@
     * Suppress warning "integer argument expected, got float" from Paramiko,
       which sometimes caused false test failures.  (Martin Pool)
 
+    * Fix bug in bundle 4 that could cause attempts to write data to wrong
+      versionedfile.  (Aaron Bentley)
+
+    * Diffs generated using "diff -p" no longer break the patch parser.
+
   IMPROVEMENTS:
 
     * ``pull`` and ``merge`` are much faster at installing bundle format 4.
@@ -18,7 +30,12 @@
     * ``pull -v`` no longer includes deltas, making it much faster.
       (Aaron Bentley)
 
-  API CHANGES:
+  API BREAKS:
+
+   * ``Branch.append_revision`` is removed altogether; please use 
+     ``Branch.set_last_revision_info`` instead.  (Martin Pool)
+
+  aPI CHANGES:
 
     * ``Transport.should_cache`` has been removed.  It was not called in the
       previous release.  (Martin Pool)

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2007-08-15 04:33:34 +0000
+++ bzrlib/branch.py	2007-08-17 05:16:14 +0000
@@ -59,6 +59,7 @@
                                       DEPRECATED_PARAMETER,
                                       deprecated_passed,
                                       zero_eight, zero_nine, zero_sixteen,
+                                      zero_ninetyone,
                                       )
 from bzrlib.trace import mutter, note
 
@@ -351,9 +352,6 @@
         """Print `file` to stdout."""
         raise NotImplementedError(self.print_file)
 
-    def append_revision(self, *revision_ids):
-        raise NotImplementedError(self.append_revision)
-
     def set_revision_history(self, rev_history):
         raise NotImplementedError(self.set_revision_history)
 
@@ -1114,13 +1112,14 @@
 
 
 class BzrBranchFormat6(BzrBranchFormat5):
-    """Branch format with last-revision
+    """Branch format with last-revision and tags.
 
     Unlike previous formats, this has no explicit revision history. Instead,
     this just stores the last-revision, and the left-hand history leading
     up to there is the history.
 
     This format was introduced in bzr 0.15
+    and became the default in 0.91.
     """
 
     def get_format_string(self):
@@ -1239,11 +1238,12 @@
 
 # formats which have no format string are not discoverable
 # and not independently creatable, so are not registered.
-__default_format = BzrBranchFormat5()
-BranchFormat.register_format(__default_format)
+__format5 = BzrBranchFormat5()
+__format6 = BzrBranchFormat6()
+BranchFormat.register_format(__format5)
 BranchFormat.register_format(BranchReferenceFormat())
-BranchFormat.register_format(BzrBranchFormat6())
-BranchFormat.set_default_format(__default_format)
+BranchFormat.register_format(__format6)
+BranchFormat.set_default_format(__format6)
 _legacy_formats = [BzrBranchFormat4(),
                    ]
 
@@ -1341,17 +1341,6 @@
         """See Branch.print_file."""
         return self.repository.print_file(file, revision_id)
 
-    @needs_write_lock
-    def append_revision(self, *revision_ids):
-        """See Branch.append_revision."""
-        revision_ids = [osutils.safe_revision_id(r) for r in revision_ids]
-        for revision_id in revision_ids:
-            _mod_revision.check_not_reserved_id(revision_id)
-            mutter("add {%s} to revision-history" % revision_id)
-        rev_history = self.revision_history()
-        rev_history.extend(revision_ids)
-        self.set_revision_history(rev_history)
-
     def _write_revision_history(self, history):
         """Factored out of set_revision_history.
 
@@ -1372,6 +1361,16 @@
 
     @needs_write_lock
     def set_last_revision_info(self, revno, revision_id):
+        """Set the last revision of this branch.
+
+        The caller is responsible for checking that the revno is correct
+        for this revision id.
+
+        It may be possible to set the branch last revision to an id not
+        present in the repository.  However, branches can also be 
+        configured to check constraints on history, in which case this may not
+        be permitted.
+        """
         revision_id = osutils.safe_revision_id(revision_id)
         history = self._lefthand_history(revision_id)
         assert len(history) == revno, '%d != %d' % (len(history), revno)
@@ -1959,25 +1958,6 @@
         self._write_last_revision_info(len(history), last_revision)
 
     @needs_write_lock
-    def append_revision(self, *revision_ids):
-        revision_ids = [osutils.safe_revision_id(r) for r in revision_ids]
-        if len(revision_ids) == 0:
-            return
-        prev_revno, prev_revision = self.last_revision_info()
-        for revision in self.repository.get_revisions(revision_ids):
-            if prev_revision == _mod_revision.NULL_REVISION:
-                if revision.parent_ids != []:
-                    raise errors.NotLeftParentDescendant(self, prev_revision,
-                                                         revision.revision_id)
-            else:
-                if revision.parent_ids[0] != prev_revision:
-                    raise errors.NotLeftParentDescendant(self, prev_revision,
-                                                         revision.revision_id)
-            prev_revision = revision.revision_id
-        self.set_last_revision_info(prev_revno + len(revision_ids),
-                                    revision_ids[-1])
-
-    @needs_write_lock
     def _set_parent_location(self, url):
         """Set the parent branch"""
         self._set_config_location('parent_location', url, make_relative=True)
@@ -2049,8 +2029,12 @@
         :param revision_id: The revision-id to truncate history at.  May
           be None to copy complete history.
         """
+        source_revno, source_revision_id = self.last_revision_info()
         if revision_id is None:
-            revno, revision_id = self.last_revision_info()
+            revno, revision_id = source_revno, source_revision_id
+        elif source_revision_id == revision_id:
+            # we know the revno without needing to walk all of history
+            revno = source_revno
         else:
             # To figure out the revno for a random revision, we need to build
             # the revision history, and count its length.

=== modified file 'bzrlib/bundle/serializer/v4.py'
--- bzrlib/bundle/serializer/v4.py	2007-08-14 23:56:36 +0000
+++ bzrlib/bundle/serializer/v4.py	2007-08-17 00:53:48 +0000
@@ -479,10 +479,10 @@
             if repo_kind == 'info':
                 assert self._info is None
                 self._handle_info(metadata)
-            if ((repo_kind, file_id) != ('file', current_file) and
-                len(pending_file_records) > 0):
-                self._install_mp_records(current_versionedfile,
-                    pending_file_records)
+            if (repo_kind, file_id) != ('file', current_file):
+                if len(pending_file_records) > 0:
+                    self._install_mp_records(current_versionedfile,
+                                             pending_file_records)
                 current_file = None
                 current_versionedfile = None
                 pending_file_records = []

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2007-08-17 07:36:52 +0000
+++ bzrlib/bzrdir.py	2007-08-20 05:48:40 +0000
@@ -2444,4 +2444,4 @@
     tree_format='bzrlib.workingtree.WorkingTreeFormat4',
     hidden=True,
     )
-format_registry.set_default('dirstate')
+format_registry.set_default('dirstate-tags')

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2007-08-10 16:17:30 +0000
+++ bzrlib/errors.py	2007-08-14 11:17:54 +0000
@@ -962,14 +962,16 @@
 
 class NoSuchRevision(BzrError):
 
-    _fmt = "Branch %(branch)s has no revision %(revision)s"
+    _fmt = "%(branch)s has no revision %(revision)s"
 
     internal_error = True
 
     def __init__(self, branch, revision):
+        # 'branch' may sometimes be an internal object like a KnitRevisionStore
         BzrError.__init__(self, branch=branch, revision=revision)
 
 
+# zero_ninetyone: this exception is no longer raised and should be removed
 class NotLeftParentDescendant(BzrError):
 
     _fmt = ("Revision %(old_revision)s is not the left parent of"

=== modified file 'bzrlib/patches.py'
--- bzrlib/patches.py	2007-03-03 05:47:31 +0000
+++ bzrlib/patches.py	2007-08-17 17:56:35 +0000
@@ -14,6 +14,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+import re
 
 
 class PatchSyntax(Exception):
@@ -94,23 +95,24 @@
 
  
 def hunk_from_header(line):
-    if not line.startswith("@@") or not line.endswith("@@\n") \
-        or not len(line) > 4:
-        raise MalformedHunkHeader("Does not start and end with @@.", line)
+    matches = re.match(r'\@\@ ([^@]*) \@\@( (.*))?\n', line)
+    if matches is None:
+        raise MalformedHunkHeader("Does not match format.", line)
     try:
-        (orig, mod) = line[3:-4].split(" ")
-    except Exception, e:
+        (orig, mod) = matches.group(1).split(" ")
+    except (ValueError, IndexError), e:
         raise MalformedHunkHeader(str(e), line)
     if not orig.startswith('-') or not mod.startswith('+'):
         raise MalformedHunkHeader("Positions don't start with + or -.", line)
     try:
         (orig_pos, orig_range) = parse_range(orig[1:])
         (mod_pos, mod_range) = parse_range(mod[1:])
-    except Exception, e:
+    except (ValueError, IndexError), e:
         raise MalformedHunkHeader(str(e), line)
     if mod_range < 0 or orig_range < 0:
         raise MalformedHunkHeader("Hunk range is negative", line)
-    return Hunk(orig_pos, orig_range, mod_pos, mod_range)
+    tail = matches.group(3)
+    return Hunk(orig_pos, orig_range, mod_pos, mod_range, tail)
 
 
 class HunkLine:
@@ -170,18 +172,24 @@
 
 
 class Hunk:
-    def __init__(self, orig_pos, orig_range, mod_pos, mod_range):
+    def __init__(self, orig_pos, orig_range, mod_pos, mod_range, tail=None):
         self.orig_pos = orig_pos
         self.orig_range = orig_range
         self.mod_pos = mod_pos
         self.mod_range = mod_range
+        self.tail = tail
         self.lines = []
 
     def get_header(self):
-        return "@@ -%s +%s @@\n" % (self.range_str(self.orig_pos, 
-                                                   self.orig_range),
-                                    self.range_str(self.mod_pos, 
-                                                   self.mod_range))
+        if self.tail is None:
+            tail_str = ''
+        else:
+            tail_str = ' ' + self.tail
+        return "@@ -%s +%s @@%s\n" % (self.range_str(self.orig_pos,
+                                                     self.orig_range),
+                                      self.range_str(self.mod_pos,
+                                                     self.mod_range),
+                                      tail_str)
 
     def range_str(self, pos, range):
         """Return a file range, special-casing for 1-line files.

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2007-08-15 11:24:06 +0000
+++ bzrlib/remote.py	2007-08-17 05:16:14 +0000
@@ -33,6 +33,10 @@
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.revision import NULL_REVISION
 from bzrlib.smart import client, vfs
+from bzrlib.symbol_versioning import (
+    deprecated_method,
+    zero_ninetyone,
+    )
 from bzrlib.trace import note
 
 # Note: RemoteBzrDirFormat is in bzrdir.py
@@ -797,6 +801,11 @@
         assert isinstance(a_bzrdir, RemoteBzrDir)
         return a_bzrdir.create_branch()
 
+    def supports_tags(self):
+        # Remote branches might support tags, but we won't know until we
+        # access the real remote branch.
+        return True
+
 
 class RemoteBranch(branch.Branch):
     """Branch stored on a server accessed by HPSS RPC.
@@ -1070,11 +1079,6 @@
         return result
 
     @needs_write_lock
-    def append_revision(self, *revision_ids):
-        self._ensure_real()
-        return self._real_branch.append_revision(*revision_ids)
-
-    @needs_write_lock
     def pull(self, source, overwrite=False, stop_revision=None,
              **kwargs):
         # FIXME: This asks the real branch to run the hooks, which means

=== modified file 'bzrlib/store/revision/knit.py'
--- bzrlib/store/revision/knit.py	2007-07-10 21:18:54 +0000
+++ bzrlib/store/revision/knit.py	2007-08-14 09:44:20 +0000
@@ -62,6 +62,10 @@
         super(KnitRevisionStore, self).__init__()
         self.versioned_file_store = versioned_file_store
 
+    def __repr__(self):
+        return "%s(%s)" % (self.__class__.__name__,
+                           self.versioned_file_store)
+
     def _add_revision(self, revision, revision_as_file, transaction):
         """Template method helper to store revision in this store."""
         # FIXME: make this ghost aware at the knit level

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2007-08-16 07:33:57 +0000
+++ bzrlib/tests/__init__.py	2007-08-17 05:08:52 +0000
@@ -1004,6 +1004,13 @@
         Note that this only captures warnings raised by symbol_versioning.warn,
         not other callers that go direct to the warning module.
 
+        To test that a deprecated method raises an error, do something like
+        this::
+
+        self.assertRaises(errors.ReservedId,
+            self.applyDeprecated, zero_ninetyone,
+                br.append_revision, 'current:')
+
         :param deprecation_format: The deprecation format that the callable
             should have been deprecated with. This is the same type as the
             parameter to deprecated_method/deprecated_function. If the

=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2007-07-06 18:30:50 +0000
+++ bzrlib/tests/blackbox/test_info.py	2007-08-14 11:17:54 +0000
@@ -483,7 +483,7 @@
         repo = branch.repository
         out, err = self.run_bzr('info branch -v')
         self.assertEqualDiff(
-"""Standalone branch (format: dirstate or knit)
+"""Standalone branch (format: dirstate-tags)
 Location:
   branch root: branch
 

=== modified file 'bzrlib/tests/branch_implementations/test_branch.py'
--- bzrlib/tests/branch_implementations/test_branch.py	2007-08-07 22:59:45 +0000
+++ bzrlib/tests/branch_implementations/test_branch.py	2007-08-17 05:01:28 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -47,25 +47,13 @@
 from bzrlib.transport.memory import MemoryServer
 from bzrlib.upgrade import upgrade
 from bzrlib.workingtree import WorkingTree
+from bzrlib.symbol_versioning import (
+    zero_ninetyone,
+    )
 
 
 class TestBranch(TestCaseWithBranch):
 
-    def test_append_revisions(self):
-        """Test appending more than one revision"""
-        wt = self.make_branch_and_tree('tree')
-        wt.commit('f', rev_id='rev1')
-        wt.commit('f', rev_id='rev2')
-        wt.commit('f', rev_id='rev3')
-
-        br = self.get_branch()
-        br.fetch(wt.branch)
-        br.append_revision("rev1")
-        self.assertEquals(br.revision_history(), ["rev1",])
-        br.append_revision("rev2", "rev3")
-        self.assertEquals(br.revision_history(), ["rev1", "rev2", "rev3"])
-        self.assertRaises(errors.ReservedId, br.append_revision, 'current:')
-
     def test_create_tree_with_merge(self):
         tree = self.create_tree_with_merge()
         ancestry_graph = tree.branch.repository.get_revision_graph('rev-3')

=== modified file 'bzrlib/tests/branch_implementations/test_hooks.py'
--- bzrlib/tests/branch_implementations/test_hooks.py	2007-03-02 18:59:00 +0000
+++ bzrlib/tests/branch_implementations/test_hooks.py	2007-08-14 11:42:58 +0000
@@ -45,10 +45,13 @@
         tree = self.make_branch_and_memory_tree('source')
         tree.lock_write()
         tree.add('')
+        tree.commit('another commit', rev_id='f\xc2\xb5')
         tree.commit('empty commit', rev_id='foo')
         tree.unlock()
         branch = tree.branch
         Branch.hooks.install_hook('set_rh', self.capture_set_rh_hook)
+        # some branches require that their history be set to a revision in the
+        # repository
         branch.set_revision_history(['f\xc2\xb5'])
         self.assertEqual(self.hook_calls,
             [('set_rh', branch, ['f\xc2\xb5'], True)])

=== modified file 'bzrlib/tests/branch_implementations/test_revision_history.py'
--- bzrlib/tests/branch_implementations/test_revision_history.py	2007-03-26 06:24:01 +0000
+++ bzrlib/tests/branch_implementations/test_revision_history.py	2007-08-14 08:38:06 +0000
@@ -14,12 +14,38 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""Tests for Branch.revision_history."""
+"""Tests for Branch.revision_history and last_revision."""
 
-from bzrlib import branch
+from bzrlib import (
+    branch,
+    errors,
+    )
 from bzrlib.tests.branch_implementations.test_branch import TestCaseWithBranch
 
 
+class TestLastRevision(TestCaseWithBranch):
+    """Tests for the last_revision property of the branch.
+    """
+
+    def test_set_last_revision_info(self):
+        # based on TestBranch.test_append_revisions, which uses the old
+        # append_revision api
+        wt = self.make_branch_and_tree('tree')
+        wt.commit('f', rev_id='rev1')
+        wt.commit('f', rev_id='rev2')
+        wt.commit('f', rev_id='rev3')
+        br = self.get_branch()
+        br.fetch(wt.branch)
+        br.set_last_revision_info(1, 'rev1')
+        self.assertEquals(br.revision_history(), ["rev1",])
+        br.set_last_revision_info(3, 'rev3')
+        self.assertEquals(br.revision_history(), ["rev1", "rev2", "rev3"])
+        # append_revision specifically prohibits some ids;
+        # set_last_revision_info currently does not
+        ## self.assertRaises(errors.ReservedId,
+        ##         br.set_last_revision_info, 4, 'current:')
+
+
 class TestRevisionHistoryCaching(TestCaseWithBranch):
     """Tests for the caching of branches' revision_history.
 

=== modified file 'bzrlib/tests/repository_implementations/__init__.py'
--- bzrlib/tests/repository_implementations/__init__.py	2007-08-15 11:24:06 +0000
+++ bzrlib/tests/repository_implementations/__init__.py	2007-08-17 05:16:14 +0000
@@ -100,6 +100,7 @@
     test_repository_implementations = [
         'bzrlib.tests.repository_implementations.test_break_lock',
         'bzrlib.tests.repository_implementations.test_commit_builder',
+        'bzrlib.tests.repository_implementations.test_fetch',
         'bzrlib.tests.repository_implementations.test_fileid_involved',
         'bzrlib.tests.repository_implementations.test_has_same_location',
         'bzrlib.tests.repository_implementations.test_iter_reverse_revision_history',

=== added file 'bzrlib/tests/repository_implementations/test_fetch.py'
--- bzrlib/tests/repository_implementations/test_fetch.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/repository_implementations/test_fetch.py	2007-08-20 05:48:40 +0000
@@ -0,0 +1,94 @@
+# Copyright (C) 2007 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Tests for fetch between repositories of the same type."""
+
+from bzrlib import (
+    bzrdir,
+    errors,
+    gpg,
+    )
+from bzrlib.tests import TestSkipped
+from bzrlib.tests.repository_implementations import TestCaseWithRepository
+from bzrlib.transport import get_transport
+
+
+class TestFetchSameRepository(TestCaseWithRepository):
+
+    def test_fetch(self):
+        # smoke test fetch to ensure that the convenience function works.
+        # it is defined as a convenience function with the underlying 
+        # functionality provided by an InterRepository
+        tree_a = self.make_branch_and_tree('a')
+        self.build_tree(['a/foo'])
+        tree_a.add('foo', 'file1')
+        tree_a.commit('rev1', rev_id='rev1')
+        # fetch with a default limit (grab everything)
+        repo = self.make_repository(self.get_url('b'))
+        if (tree_a.branch.repository.supports_rich_root() and not
+            repo.supports_rich_root()):
+            raise TestSkipped('Cannot fetch from model2 to model1')
+        repo.fetch(tree_a.branch.repository,
+                   revision_id=None)
+                   ## pb=bzrlib.progress.DummyProgress())
+
+    def test_fetch_knit3(self):
+        # create a repository of the sort we are testing.
+        tree_a = self.make_branch_and_tree('a', '')
+        self.build_tree(['a/foo'])
+        tree_a.add('foo', 'file1')
+        tree_a.commit('rev1', rev_id='rev1')
+        # create a knit-3 based format to fetch into
+        f = bzrdir.format_registry.make_bzrdir('dirstate-with-subtree')
+        try:
+            format = tree_a.branch.repository._format
+            format.check_conversion_target(f.repository_format)
+            # if we cannot convert data to knit3, skip the test.
+        except errors.BadConversionTarget, e:
+            raise TestSkipped(str(e))
+        self.get_transport().mkdir('b')
+        b_bzrdir = f.initialize(self.get_url('b'))
+        knit3_repo = b_bzrdir.create_repository()
+        # fetch with a default limit (grab everything)
+        knit3_repo.fetch(tree_a.branch.repository, revision_id=None)
+        rev1_tree = knit3_repo.revision_tree('rev1')
+        lines = rev1_tree.get_file_lines(rev1_tree.inventory.root.file_id)
+        self.assertEqual([], lines)
+        b_branch = b_bzrdir.create_branch()
+        b_branch.pull(tree_a.branch)
+        try:
+            tree_b = b_bzrdir.create_workingtree()
+        except errors.NotLocalUrl:
+            raise TestSkipped("cannot make working tree with transport %r"
+                              % b_bzrdir.transport)
+        tree_b.commit('no change', rev_id='rev2')
+        rev2_tree = knit3_repo.revision_tree('rev2')
+        self.assertEqual('rev1', rev2_tree.inventory.root.revision)
+
+    def makeARepoWithSignatures(self):
+        wt = self.make_branch_and_tree('a-repo-with-sigs')
+        wt.commit('rev1', allow_pointless=True, rev_id='rev1')
+        repo = wt.branch.repository
+        repo.sign_revision('rev1', gpg.LoopbackGPGStrategy(None))
+        return repo
+
+    def test_fetch_copies_signatures(self):
+        source_repo = self.makeARepoWithSignatures()
+        target_repo = self.make_repository('target')
+        target_repo.fetch(source_repo, revision_id=None)
+        self.assertEqual(
+            source_repo.get_signature_text('rev1'),
+            target_repo.get_signature_text('rev1'))

=== modified file 'bzrlib/tests/repository_implementations/test_repository.py'
--- bzrlib/tests/repository_implementations/test_repository.py	2007-08-17 07:21:24 +0000
+++ bzrlib/tests/repository_implementations/test_repository.py	2007-08-20 05:48:40 +0000
@@ -160,71 +160,6 @@
         tree = wt.branch.repository.revision_tree(NULL_REVISION)
         self.assertEqual([], list(tree.list_files(include_root=True)))
 
-    def test_fetch(self):
-        # smoke test fetch to ensure that the convenience function works.
-        # it is defined as a convenience function with the underlying 
-        # functionality provided by an InterRepository
-        tree_a = self.make_branch_and_tree('a')
-        self.build_tree(['a/foo'])
-        tree_a.add('foo', 'file1')
-        tree_a.commit('rev1', rev_id='rev1')
-        # fetch with a default limit (grab everything)
-        repo = self.make_repository('b')
-        if (tree_a.branch.repository.supports_rich_root() and not
-            repo.supports_rich_root()):
-            raise TestSkipped('Cannot fetch from model2 to model1')
-        repo.fetch(tree_a.branch.repository,
-                   revision_id=None,
-                   pb=bzrlib.progress.DummyProgress())
-
-    def test_fetch_knit3(self):
-        # create a repository of the sort we are testing.
-        tree_a = self.make_branch_and_tree('a', '')
-        self.build_tree(['a/foo'])
-        tree_a.add('foo', 'file1')
-        tree_a.commit('rev1', rev_id='rev1')
-        # create a knit-3 based format to fetch into
-        f = bzrdir.format_registry.make_bzrdir('dirstate-with-subtree')
-        try:
-            format = tree_a.branch.repository._format
-            format.check_conversion_target(f.repository_format)
-            # if we cannot convert data to knit3, skip the test.
-        except errors.BadConversionTarget, e:
-            raise TestSkipped(str(e))
-        self.get_transport().mkdir('b')
-        b_bzrdir = f.initialize(self.get_url('b'))
-        knit3_repo = b_bzrdir.create_repository()
-        # fetch with a default limit (grab everything)
-        knit3_repo.fetch(tree_a.branch.repository, revision_id=None)
-        rev1_tree = knit3_repo.revision_tree('rev1')
-        lines = rev1_tree.get_file_lines(rev1_tree.inventory.root.file_id)
-        self.assertEqual([], lines)
-        b_branch = b_bzrdir.create_branch()
-        b_branch.pull(tree_a.branch)
-        try:
-            tree_b = b_bzrdir.create_workingtree()
-        except errors.NotLocalUrl:
-            raise TestSkipped("cannot make working tree with transport %r"
-                              % b_bzrdir.transport)
-        tree_b.commit('no change', rev_id='rev2')
-        rev2_tree = knit3_repo.revision_tree('rev2')
-        self.assertEqual('rev1', rev2_tree.inventory.root.revision)
-
-    def makeARepoWithSignatures(self):
-        wt = self.make_branch_and_tree('a-repo-with-sigs')
-        wt.commit('rev1', allow_pointless=True, rev_id='rev1')
-        repo = wt.branch.repository
-        repo.sign_revision('rev1', bzrlib.gpg.LoopbackGPGStrategy(None))
-        return repo
-
-    def test_fetch_copies_signatures(self):
-        source_repo = self.makeARepoWithSignatures()
-        target_repo = self.make_repository('target')
-        target_repo.fetch(source_repo, revision_id=None)
-        self.assertEqual(
-            source_repo.get_signature_text('rev1'),
-            target_repo.get_signature_text('rev1'))
-
     def test_get_revision_delta(self):
         tree_a = self.make_branch_and_tree('a')
         self.build_tree(['a/foo'])

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2007-07-04 14:53:53 +0000
+++ bzrlib/tests/test_branch.py	2007-08-14 11:53:00 +0000
@@ -39,6 +39,7 @@
     BranchReferenceFormat,
     BzrBranch5,
     BzrBranchFormat5,
+    BzrBranchFormat6,
     PullResult,
     )
 from bzrlib.bzrdir import (BzrDirMetaFormat1, BzrDirMeta1, 
@@ -54,10 +55,21 @@
 
 class TestDefaultFormat(TestCase):
 
+    def test_default_format(self):
+        # update this if you change the default branch format
+        self.assertIsInstance(BranchFormat.get_default_format(),
+                BzrBranchFormat6)
+
+    def test_default_format_is_same_as_bzrdir_default(self):
+        # XXX: it might be nice if there was only one place the default was
+        # set, but at the moment that's not true -- mbp 20070814 -- 
+        # https://bugs.launchpad.net/bzr/+bug/132376
+        self.assertEqual(BranchFormat.get_default_format(),
+                BzrDirFormat.get_default_format().get_branch_format())
+
     def test_get_set_default_format(self):
+        # set the format and then set it back again
         old_format = BranchFormat.get_default_format()
-        # default is 5
-        self.assertTrue(isinstance(old_format, BzrBranchFormat5))
         BranchFormat.set_default_format(SampleBranchFormat())
         try:
             # the default branch format is used by the meta dir format
@@ -224,32 +236,6 @@
         finally:
             tree.unlock()
 
-    def test_append_revision(self):
-        tree = self.make_branch_and_tree('branch1',
-            format='dirstate-tags')
-        tree.lock_write()
-        try:
-            tree.commit('foo', rev_id='foo')
-            tree.commit('bar', rev_id='bar')
-            tree.commit('baz', rev_id='baz')
-            tree.set_last_revision('bar')
-            tree.branch.set_last_revision_info(2, 'bar')
-            tree.commit('qux', rev_id='qux')
-            tree.add_parent_tree_id('baz')
-            tree.commit('qux', rev_id='quxx')
-            tree.branch.set_last_revision_info(0, 'null:')
-            self.assertRaises(errors.NotLeftParentDescendant,
-                              tree.branch.append_revision, 'bar')
-            tree.branch.append_revision('foo')
-            self.assertRaises(errors.NotLeftParentDescendant,
-                              tree.branch.append_revision, 'baz')
-            tree.branch.append_revision('bar')
-            tree.branch.append_revision('baz')
-            self.assertRaises(errors.NotLeftParentDescendant,
-                              tree.branch.append_revision, 'quxx')
-        finally:
-            tree.unlock()
-
     def do_checkout_test(self, lightweight=False):
         tree = self.make_branch_and_tree('source', format='dirstate-with-subtree')
         subtree = self.make_branch_and_tree('source/subtree',
@@ -276,7 +262,6 @@
         else:
             self.assertEndsWith(subbranch.base, 'target/subtree/subsubtree/')
 
-
     def test_checkout_with_references(self):
         self.do_checkout_test()
 

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2007-08-14 23:35:48 +0000
+++ bzrlib/tests/test_bundle.py	2007-08-17 16:19:09 +0000
@@ -1063,6 +1063,33 @@
                               " slashes")
         bundle = self.get_valid_bundle('null:', 'rev/id')
 
+    def test_skip_file(self):
+        """Make sure we don't accidentally write to the wrong versionedfile"""
+        self.tree1 = self.make_branch_and_tree('tree')
+        self.b1 = self.tree1.branch
+        # rev1 is not present in bundle, done by fetch
+        self.build_tree_contents([('tree/file2', 'contents1')])
+        self.tree1.add('file2', 'file2-id')
+        self.tree1.commit('rev1', rev_id='reva')
+        self.build_tree_contents([('tree/file3', 'contents2')])
+        # rev2 is present in bundle, and done by fetch
+        # having file1 in the bunle causes file1's versionedfile to be opened.
+        self.tree1.add('file3', 'file3-id')
+        self.tree1.commit('rev2')
+        # Updating file2 should not cause an attempt to add to file1's vf
+        target = self.tree1.bzrdir.sprout('target').open_workingtree()
+        self.build_tree_contents([('tree/file2', 'contents3')])
+        self.tree1.commit('rev3', rev_id='rev3')
+        bundle = self.get_valid_bundle('reva', 'rev3')
+        if getattr(bundle, 'get_bundle_reader', None) is None:
+            raise TestSkipped('Bundle format cannot provide reader')
+        # be sure that file1 comes before file2
+        for b, m, k, r, f in bundle.get_bundle_reader().iter_records():
+            if f == 'file3-id':
+                break
+            self.assertNotEqual(f, 'file2-id')
+        bundle.install_revisions(target.branch.repository)
+
 
 class V08BundleTester(BundleTester, TestCaseWithTransport):
 

=== modified file 'bzrlib/tests/test_fetch.py'
--- bzrlib/tests/test_fetch.py	2007-07-25 22:03:13 +0000
+++ bzrlib/tests/test_fetch.py	2007-08-17 05:16:14 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Canonical Ltd
+# Copyright (C) 2005, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 import re
 import sys
 
+import bzrlib
 from bzrlib import (
     bzrdir,
     errors,
@@ -26,8 +27,10 @@
     )
 from bzrlib.branch import Branch
 from bzrlib.bzrdir import BzrDir
-import bzrlib.errors
 from bzrlib.repofmt import knitrepo
+from bzrlib.symbol_versioning import (
+    zero_ninetyone,
+    )
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.tests.HTTPTestUtil import TestCaseWithWebserver
 from bzrlib.tests.test_revision import make_branches
@@ -35,6 +38,10 @@
 from bzrlib.upgrade import Convert
 from bzrlib.workingtree import WorkingTree
 
+# These tests are a bit old; please instead add new tests into
+# interrepository_implementations/ so they'll run on all relevant
+# combinations.
+
 
 def has_revision(branch, revision_id):
     return branch.repository.has_revision(revision_id)
@@ -94,18 +101,13 @@
     self.assertEquals(fetched, 3, "fetched %d instead of 3" % fetched)
     # InstallFailed should be raised if the branch is missing the revision
     # that was requested.
-    self.assertRaises(bzrlib.errors.InstallFailed, br_a3.fetch, br_a2, 'pizza')
-    # InstallFailed should be raised if the branch is missing a revision
-    # from its own revision history
-    br_a2.append_revision('a-b-c')
-    self.assertRaises(bzrlib.errors.InstallFailed, br_a3.fetch, br_a2)
+    self.assertRaises(errors.InstallFailed, br_a3.fetch, br_a2, 'pizza')
 
-    # TODO: ADHB 20070116 Perhaps set_last_revision shouldn't accept
-    #       revisions which are not present?  In that case, this test
-    #       must be rewritten.
-    #
-    #       RBC 20060403 the way to do this is to uncommit the revision from
-    #       the repository after the commit
+    # TODO: Test trying to fetch from a branch that points to a revision not
+    # actually present in its repository.  Not every branch format allows you
+    # to directly point to such revisions, so it's a bit complicated to
+    # construct.  One way would be to uncommit and gc the revision, but not
+    # every branch supports that.  -- mbp 20070814
 
     #TODO: test that fetch correctly does reweaving when needed. RBC 20051008
     # Note that this means - updating the weave when ghosts are filled in to 
@@ -116,7 +118,7 @@
 
     def test_fetch(self):
         #highest indices a: 5, b: 7
-        br_a, br_b = make_branches(self)
+        br_a, br_b = make_branches(self, format='dirstate-tags')
         fetch_steps(self, br_a, br_b, br_a)
 
     def test_fetch_self(self):

=== modified file 'bzrlib/tests/test_lockdir.py'
--- bzrlib/tests/test_lockdir.py	2007-08-16 12:43:01 +0000
+++ bzrlib/tests/test_lockdir.py	2007-08-17 08:10:01 +0000
@@ -395,7 +395,7 @@
         unlocker.start()
         try:
             # Wait and play against the other thread
-            lf2.wait_lock(timeout=1.0, poll=0.01)
+            lf2.wait_lock(timeout=20.0, poll=0.01)
         finally:
             unlocker.join()
         lf2.unlock()

=== modified file 'bzrlib/tests/test_patches.py'
--- bzrlib/tests/test_patches.py	2007-03-03 05:47:31 +0000
+++ bzrlib/tests/test_patches.py	2007-08-17 13:47:21 +0000
@@ -74,6 +74,13 @@
         assert (hunk.mod_range == 0)
         assert (str(hunk) == header)
 
+    def testPDiff(self):
+        """Parse a hunk header produced by diff -p"""
+        header = "@@ -407,7 +292,7 @@ bzr 0.18rc1  2007-07-10\n"
+        hunk = hunk_from_header(header)
+        self.assertEqual('bzr 0.18rc1  2007-07-10', hunk.tail)
+        self.assertEqual(header, str(hunk))
+
     def makeMalformed(self, header):
         self.assertRaises(MalformedHunkHeader, hunk_from_header, header)
 

=== modified file 'bzrlib/tests/test_revision.py'
--- bzrlib/tests/test_revision.py	2007-06-08 21:48:42 +0000
+++ bzrlib/tests/test_revision.py	2007-08-14 09:44:20 +0000
@@ -39,7 +39,7 @@
         r'bzrlib\.tests\.test_revision')
 
 # XXX: Make this a method of a merge base case
-def make_branches(self):
+def make_branches(self, format=None):
     """Create two branches
 
     branch 1 has 6 commits, branch 2 has 3 commits
@@ -58,7 +58,7 @@
     so A is missing b6 at the start
     and B is missing a3, a4, a5
     """
-    tree1 = self.make_branch_and_tree("branch1")
+    tree1 = self.make_branch_and_tree("branch1", format=format)
     br1 = tree1.branch
     
     tree1.commit("Commit one", rev_id="a@u-0-0")

=== modified file 'bzrlib/transport/ssh.py'
--- bzrlib/transport/ssh.py	2007-03-07 13:47:47 +0000
+++ bzrlib/transport/ssh.py	2007-05-12 19:05:12 +0000
@@ -524,12 +524,12 @@
     global SYSTEM_HOSTKEYS, BZR_HOSTKEYS
     try:
         SYSTEM_HOSTKEYS = paramiko.util.load_host_keys(os.path.expanduser('~/.ssh/known_hosts'))
-    except Exception, e:
+    except IOError, e:
         mutter('failed to load system host keys: ' + str(e))
     bzr_hostkey_path = pathjoin(config_dir(), 'ssh_host_keys')
     try:
         BZR_HOSTKEYS = paramiko.util.load_host_keys(bzr_hostkey_path)
-    except Exception, e:
+    except IOError, e:
         mutter('failed to load bzr host keys: ' + str(e))
         save_host_keys()
 

